@@ -24,7 +24,34 @@ module Schleuder
       resend_it_cc(arguments, mail, true)
     end
 
+    def self.resend_unencrypted(arguments, list, mail)
+      do_resend_unencrypted(arguments, list, mail, :to)
+    end
+
+    def self.resend_cc_unencrypted(arguments, list, mail)
+      do_resend_unencrypted(arguments, list, mail, :cc)
+    end
+
+    # helper methods
+    private
+
+    def self.do_resend_unencrypted(arguments, list, mail, target)
+      if ! resend_recipients_valid?(mail, arguments)
+        return false
+      end
+
+      recip_map = Hash[Array(arguments).map{|email| [email,''] }]
+
+      if do_resend(mail, recip_map, target, false)
+        mail.add_subject_prefix_out!
+      end
+    end
+
     def self.resend_it_cc(arguments, mail, encrypted_only)
+      if ! resend_recipients_valid?(mail, arguments)
+        return false
+      end
+
       recip_map = map_with_keys(mail, arguments, encrypted_only)
 
       # Only continue if all recipients are still here.
@@ -38,6 +65,10 @@ module Schleuder
     end
 
     def self.resend_it(arguments, mail, encrypted_only)
+      if ! resend_recipients_valid?(mail, arguments)
+        return false
+      end
+
       recip_map = map_with_keys(mail, arguments, encrypted_only)
 
       resent_stati = recip_map.map do |email, key|
@@ -63,7 +94,7 @@ module Schleuder
       # Compose and send email
       new = mail.clean_copy
       new[to_or_cc] = recipients_map.keys
-      new.add_footer!
+      new.add_public_footer!
       new.sender = mail.list.bounce_address
       # `dup` gpg_opts because `deliver` changes their value and we need them
       # below to determine encryption!
@@ -150,5 +181,16 @@ module Schleuder
         'resent_cc'
       end
     end
+
+    def self.resend_recipients_valid?(mail, recipients)
+      all_valid = true
+      Array(recipients).each do |address|
+        if ! address.match(Conf::EMAIL_REGEXP)
+          mail.add_pseudoheader(:error, I18n.t("plugins.resend.invalid_recipient", address: address))
+          all_valid = false
+        end
+      end
+      all_valid
+    end
   end
 end
