@@ -23,10 +23,11 @@ module Schleuder
     end
 
     def fingerprint=(arg)
-      # Allow input to contain whitespace and '0x'-prefix, but don't store it
-      # into the DB.
-      value = arg.to_s.gsub(/\s*/, '').gsub(/^0x/, '').chomp
-      write_attribute(:fingerprint, value)
+      # Always assign the given value, because it must be possible to overwrite
+      # the previous fingerprint with an empty value. That value should better
+      # be nil instead of a blank string, but currently schleuder-cli (v0.1.0) expects
+      # only strings.
+      write_attribute(:fingerprint, arg.to_s.gsub(/\s*/, '').gsub(/^0x/, '').chomp.upcase)
     end
 
     def key
@@ -39,11 +40,6 @@ module Schleuder
     def send_mail(mail)
       list.logger.debug "Preparing sending to #{self.inspect}"
 
-      if ! self.delivery_enabled
-        list.logger.info "Not sending to #{self.email}: delivery is disabled."
-        return false
-      end
-
       mail = ensure_headers(mail)
       gpg_opts = self.list.gpg_sign_options
 
