@@ -227,5 +227,31 @@ describe GPGME::Ctx do
         expect(mail.to_s).to match(/gpgkeys: .* error .* connect/)
       end
     end
+
+    it 'does not import non-self-signatures if gpg >= 2.1.15; or else sends a warning' do
+      list = create(:list)
+      list.delete_key('87E65ED2081AE3D16BE4F0A5EBDBE899251F2412')
+      list.subscribe('admin@example.org', nil, true)
+      list.import_key(File.read('spec/fixtures/bla_foo_key.txt'))
+
+      res = ''
+      with_sks_mock do
+        res = list.gpg.refresh_keys(list.keys)
+      end
+      # GPGME apparently does not show signatures correctly in some cases, so we better use gpgcli.
+      signature_output = list.gpg.class.gpgcli(['--list-sigs', '87E65ED2081AE3D16BE4F0A5EBDBE899251F2412'])[1].grep(/0F759BD3.*schleuder@example.org/)
+
+      if GPGME::Ctx.sufficient_gpg_version?('2.1.15')
+        expect(res).to be_empty
+        expect(signature_output).to be_empty
+      else
+        message = Mail::TestMailer.deliveries.first
+        expect(message.to).to eql([Conf.superadmin])
+        expect(message.subject).to eql('Schleuder installation problem')
+        expect(res).not_to be_empty
+        expect(signature_output).not_to be_empty
+      end
+    end
+
   end
 end
