@@ -23,6 +23,8 @@ class SksMock < Sinatra::Base
       File.read('spec/fixtures/olduid_key_with_newuid.txt')
     when '0x59C71FB38AEE22E091C78259D06350440F759BD3'
       File.read('spec/fixtures/default_list_key.txt')
+    when '0x87E65ED2081AE3D16BE4F0A5EBDBE899251F2412'
+      File.read('spec/fixtures/openpgp-keys/public-key-with-third-party-signature.txt')
     else
       404
     end
